ewa.wsgiapp.EwaApp

Package ewa :: Module wsgiapp :: Class EwaApp |
[hide private]
[frames] | no frames]

# Class EwaApp

source code

    object --+
             |
            EwaApp

Instance Methods | [hide private]
__init__(self, rule, basedir, targetdir=None, stream=False, refresh_rate=0, use_xsendfile=True, sendfile_header=`'``X-Sendfile``'`, content_disposition=`'````'`, **spliceKwargs) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
send(self, start_response, status, headers=None, iterable=None) | source code
_create_combined(self, mp3file) | source code
__call__(self, environ, start_response) | source code
sendfile(self, result, start_response, mtype) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
| basedir
| targetdir basedir
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, rule, basedir, targetdir=None, stream=False, refresh_rate=0, use_xsendfile=True, sendfile_header=`'``X-Sendfile``'`, content_disposition=`'````'`, **spliceKwargs) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

Property Details | [hide private]

### basedir Get Method: unreachable(x)

### targetdir basedir Get Method: unreachable(x) - basedir